ProSHADE: src/proshade/ProSHADE_io.cpp File Reference

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

ProSHADE_io.cpp File Reference

This source file contains the functions required for specifc data format manipulations. More...

`#include "ProSHADE_io.hpp"`

Go to the source code of this file.

## Detailed Description

This source file contains the functions required for specifc data format manipulations.

The functions in this source file are required for detection of supported input and output formats as well as reading and writing into the supported formats. They are the lowest level functions ProSHADE has for disk access.

Copyright by Michal Tykac and individual contributors. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 1) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer. 2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 3) Neither the name of Michal Tykac nor the names of this code's contributors may be used to endorse or promote products derived from this software without specific prior written permission.

This software is provided by the copyright holder and contributors "as is" and any express or implied warranties, including, but not limitted to, the implied warranties of merchantibility and fitness for a particular purpose are disclaimed. In no event shall the copyright owner or the contributors be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, but not limitted to, procurement of substitute goods or services, loss of use, data or profits, or business interuption) however caused and on any theory of liability, whether in contract, strict liability or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damage.

Author
  Michal Tykac
  Garib N. Murshudov

Version
  0.7.5.4

Date
  MAR 2021

Definition in file ProSHADE_io.cpp.